/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
 *
 * Copyright 2009-2010  Red Hat, Inc,
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * Written by: Matthias Clasen <mclasen@redhat.com>
 */

#include "config.h"

#include <glib.h>
#include <glib/gi18n.h>
#include <glib-object.h>

#include <gtk/gtk.h>
#include <stdio.h>
#include <string.h>

#include "um-account-type.h"
#include "um-user.h"

const gchar *
um_account_type_get_name (UmAccountType account_type)
{
        switch (account_type) {
        case UM_ACCOUNT_TYPE_STANDARD:
                return C_("Account type", "Standard");
        case UM_ACCOUNT_TYPE_ADMINISTRATOR:
                return C_("Account type", "Administrator");
        default:
                g_assert_not_reached ();
        }
}

/*RM_EDIT from here downward*/
//void um_account_type_add_stored (GtkWidget *widget) 
void um_account_type_add_stored (GtkTreeModel *model)
{
        GVariant *variant;
        GVariantIter *vi;
        GError *role_error = NULL;
        GError *error = NULL;
        const char *str;
        GDBusProxy *proxy;
        
        //GtkTreeModel *model;
        GtkTreeIter iter;
        
        //model = gtk_combo_box_get_model (widget);
        GtkListStore *store = GTK_LIST_STORE (model);

        proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
                                               G_DBUS_PROXY_FLAGS_NONE,
                                               NULL,
                                               "org.freedesktop.Accounts",
                                               "/org/freedesktop/Accounts",
                                               "org.freedesktop.Accounts",
                                               NULL,
                                               NULL);
        if (proxy == NULL)
                return;

        variant = g_dbus_proxy_call_sync (proxy,
                                          "ListRoles",
                                          NULL,
                                          G_DBUS_CALL_FLAGS_NONE,
                                          -1,
                                          NULL,
                                          &role_error);
        if (variant == NULL) {
                g_warning ("Failed to list existing roles: %s", role_error->message);
                g_error_free (role_error);
                g_object_unref (proxy);
                return;
        }
        g_variant_get (variant, "(ao)", &vi);
        while (g_variant_iter_loop (vi, "o", &str)) {
                GDBusProxy *role;
                GVariant *temp;
                const char *role_name;
                
                role = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
                                                      G_DBUS_PROXY_FLAGS_NONE,
                                                      NULL,
                                                      "org.freedesktop.Accounts",
                                                      str,
                                                      "org.freedesktop.Accounts.Role",
                                                      NULL,
                                                      &role_error);
                
                if (role == NULL) {
                        g_warning ("Failed to get proxy for role '%s': %s",
                                   str, error->message);
                        g_error_free (role_error);
                        role_error = NULL;
                } else {
                        gchar *role_display_name;
                        gchar *role_id;
                        temp = g_dbus_proxy_get_cached_property (role, "DisplayName");
                        g_variant_get (temp, "s", &role_display_name);
                        g_variant_unref (temp);
                        temp = g_dbus_proxy_get_cached_property (role, "id");
                        g_variant_get (temp, "s", &role_id);
                        g_variant_unref (temp);
                        gtk_list_store_append (store, &iter);
                        gtk_list_store_set (store, &iter, 0, role_display_name, 1, 10, 2, role_id, -1);
                }
        }
        
        gtk_list_store_append (store, &iter);
        gtk_list_store_set (store, &iter, 0, "Manage...", 1, 100, 2, "none", -1);
}

 void um_account_type_profile_changed (UmUser *user, gchar *account_profile)
{
        gchar * role;
        role = g_strconcat ("/org/freedesktop/Roles/", account_profile, NULL);
        um_user_set_role (user, role);
        g_free (role);
        return;
}